@@ -8,11 +8,11 @@
 import sys, os, shutil, subprocess
 
 h_array = ['--fhead',
-           "#ifndef __GST_APP_ENUM_TYPES_H__\n#define __GST_APP_ENUM_TYPES_H__\n\n#include <gst/gst.h>\n#include <gst/app/app-prelude.h>\nG_BEGIN_DECLS\n",
+           "#ifndef __GST_APP_ENUM_TYPES_H__\n#define __GST_APP_ENUM_TYPES_H__\n\n#include <glib-object.h>\n\nG_BEGIN_DECLS\n",
            '--fprod',
            "\n/* enumerations from \"@filename@\" */\n",
            '--vhead',
-           'GST_APP_API GType @enum_name@_get_type (void);\n#define GST_TYPE_@ENUMSHORT@ (@enum_name@_get_type())\n',
+           'GType @enum_name@_get_type (void);\n#define GST_TYPE_@ENUMSHORT@ (@enum_name@_get_type())\n',
            '--ftail',
            'G_END_DECLS\n\n#endif /* __GST_APP_ENUM_TYPES_H__ */',
            ]
@@ -37,7 +37,7 @@ argn = 1
 for arg in sys.argv[1:]:
     cmd.append(arg)
     argn += 1
-    if os.path.splitext(arg)[0].endswith('glib-mkenums'):
+    if arg.endswith('glib-mkenums'):
         break
 ofilename = sys.argv[argn]
 headers = sys.argv[argn + 1:]
