@@ -17,64 +17,6 @@
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-/**
- * SECTION:encoding-target
- *
- * On top of the notion of profiles, we implement the notion of EncodingTarget.
- * Encoding Targets are basically a higher level of abstraction to define formats
- * for specific target types. Those can define several GstEncodingProfiles with
- * different names, for example one for transcoding in full HD, another one for
- * low res, etc.. which are defined in the same encoding target.
- *
- * Basically if you want to encode a stream to send it to, say, youtube you should
- * have a Youtube encoding target defined in the "online-service" category.
- *
- * ## Encoding target serialization format
- *
- * Encoding targets are serialized in a KeyFile like files.
- *
- * |[
- * [GStreamer Encoding Target]
- * name : <name>
- * category : <category>
- * \description : <description> #translatable
- *
- * [profile-<profile1name>]
- * name : <name>
- * \description : <description> #optional
- * format : <format>
- * preset : <preset>
- *
- * [streamprofile-<id>]
- * parent : <encodingprofile.name>[,<encodingprofile.name>..]
- * \type : <type> # "audio", "video", "text"
- * format : <format>
- * preset : <preset>
- * restriction : <restriction>
- * presence : <presence>
- * pass : <pass>
- * variableframerate : <variableframerate>
- * ]|
- *
- * ## Location of encoding target files
- *
- * $GST_DATADIR/gstreamer-GST_API_VERSION/encoding-profile
- * $HOME/gstreamer-GST_API_VERSION/encoding-profile
- *
- * There also is a GST_ENCODING_TARGET_PATH environment variable
- * defining a list of folder containing encoding target files.
- *
- * ## Naming convention
- *
- * |[
- *   $(target.category)/$(target.name).gep
- * ]|
- *
- * ## Naming restrictions:
- *
- *  * lowercase ASCII letter for the first character
- *  * Same for all other characters + numerics + hyphens
- */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -84,31 +26,9 @@
 #include <errno.h>
 #include <string.h>
 #include "encoding-target.h"
-#include "pbutils-private.h"
 
 /* Documented in encoding-profile.c */
 
-#ifndef GST_DISABLE_GST_DEBUG
-#define GST_CAT_DEFAULT gst_pb_utils_encoding_target_ensure_debug_category()
-
-static GstDebugCategory *
-gst_pb_utils_encoding_target_ensure_debug_category (void)
-{
-  static gsize cat_gonce = 0;
-
-  if (g_once_init_enter (&cat_gonce)) {
-    GstDebugCategory *cat = NULL;
-
-    GST_DEBUG_CATEGORY_INIT (cat, "encoding-target", 0,
-        "GstPbUtils encoding target");
-
-    g_once_init_leave (&cat_gonce, (gsize) cat);
-  }
-
-  return (GstDebugCategory *) cat_gonce;
-}
-#endif /* GST_DISABLE_GST_DEBUG */
-
 #define GST_ENCODING_TARGET_HEADER "GStreamer Encoding Target"
 #define GST_ENCODING_TARGET_DIRECTORY "encoding-profiles"
 #define GST_ENCODING_TARGET_SUFFIX ".gep"
@@ -120,7 +40,6 @@ struct _GstEncodingTarget
   gchar *name;
   gchar *category;
   gchar *description;
-  gchar *path;
   GList *profiles;
 
   /*< private > */
@@ -145,12 +64,9 @@ gst_encoding_target_finalize (GObject * object)
   g_free (target->name);
   g_free (target->category);
   g_free (target->description);
-  g_free (target->path);
 
   g_list_foreach (target->profiles, (GFunc) g_object_unref, NULL);
   g_list_free (target->profiles);
-
-  G_OBJECT_CLASS (gst_encoding_target_parent_class)->finalize (object);
 }
 
 static void
@@ -196,21 +112,6 @@ gst_encoding_target_get_description (GstEncodingTarget * target)
   return target->description;
 }
 
-/**
- * gst_encoding_target_get_path:
- * @target: a #GstEncodingTarget
- *
- * Returns: (transfer none) (nullable) (type filename): The path to the @target file.
- *
- * Since: 1.18
- */
-const gchar *
-gst_encoding_target_get_path (GstEncodingTarget * target)
-{
-  g_return_val_if_fail (GST_IS_ENCODING_TARGET (target), NULL);
-  return target->path;
-}
-
 /**
  * gst_encoding_target_get_profiles:
  * @target: a #GstEncodingTarget
@@ -229,7 +130,7 @@ gst_encoding_target_get_profiles (GstEncodingTarget * target)
  * @target: a #GstEncodingTarget
  * @name: the name of the profile to retrieve
  *
- * Returns: (nullable) (transfer full): The matching #GstEncodingProfile, or %NULL.
+ * Returns: (transfer full): The matching #GstEncodingProfile, or %NULL.
  */
 GstEncodingProfile *
 gst_encoding_target_get_profile (GstEncodingTarget * target, const gchar * name)
@@ -306,12 +207,12 @@ validate_name (const gchar * name)
  * first character, followed by either lowercase ASCII letters, digits or
  * hyphens ('-').
  *
- * The @category *should* be one of the existing
+ * The @category <emphasis>should</emphasis> be one of the existing
  * well-defined categories, like #GST_ENCODING_CATEGORY_DEVICE, but it
- * *can* be a application or user specific category if
+ * <emphasis>can</emphasis> be a application or user specific category if
  * needed.
  *
- * Returns: (transfer full) (nullable): The newly created #GstEncodingTarget or %NULL if
+ * Returns: (transfer full): The newly created #GstEncodingTarget or %NULL if
  * there was an error.
  */
 
@@ -467,8 +368,6 @@ get_locale (void)
   const char *loc = NULL;
   gchar *ret;
 
-  gst_pb_utils_init_locale_text_domain ();
-
 #ifdef ENABLE_NLS
 #if defined(LC_MESSAGES)
   loc = setlocale (LC_MESSAGES, NULL);
@@ -642,8 +541,6 @@ parse_encoding_profile (GKeyFile * in, gchar * parentprofilename,
   proftype = g_key_file_get_value (in, profilename, "type", NULL);
   if (!proftype) {
     GST_WARNING ("Missing 'type' field for streamprofile %s", profilename);
-    g_free (pname);
-    g_free (description);
     return NULL;
   }
 
@@ -799,8 +696,8 @@ empty_name:
 
 /**
  * gst_encoding_target_load_from_file:
- * @filepath: (type filename): The file location to load the #GstEncodingTarget from
- * @error: If an error occurred, this field will be filled in.
+ * @filepath: The file location to load the #GstEncodingTarget from
+ * @error: If an error occured, this field will be filled in.
  *
  * Opens the provided file and returns the contained #GstEncodingTarget.
  *
@@ -902,9 +799,9 @@ gst_encoding_target_subload (gchar * path, const gchar * category,
  * @name: the name of the #GstEncodingTarget to load (automatically
  * converted to lower case internally as capital letters are not
  * valid for target names).
- * @category: (nullable): the name of the target category, like
+ * @category: (allow-none): the name of the target category, like
  * #GST_ENCODING_CATEGORY_DEVICE. Can be %NULL
- * @error: If an error occurred, this field will be filled in.
+ * @error: If an error occured, this field will be filled in.
  *
  * Searches for the #GstEncodingTarget with the given name, loads it
  * and returns it.
@@ -1003,12 +900,12 @@ done:
 
 invalid_name:
   {
-    GST_INFO ("Invalid name for encoding target : '%s'", name);
+    GST_ERROR ("Invalid name for encoding target : '%s'", name);
     goto done;
   }
 invalid_category:
   {
-    GST_INFO ("Invalid name for encoding category : '%s'", category);
+    GST_ERROR ("Invalid name for encoding category : '%s'", category);
     goto done;
   }
 }
@@ -1016,8 +913,8 @@ invalid_category:
 /**
  * gst_encoding_target_save_to_file:
  * @target: a #GstEncodingTarget
- * @filepath: (type filename): the location to store the @target at.
- * @error: If an error occurred, this field will be filled in.
+ * @filepath: the location to store the @target at.
+ * @error: If an error occured, this field will be filled in.
  *
  * Saves the @target to the provided file location.
  *
@@ -1052,8 +949,6 @@ gst_encoding_target_save_to_file (GstEncodingTarget * target,
   if (!g_file_set_contents (filepath, data, data_size, error))
     goto write_failed;
 
-  target->path = g_strdup (filepath);
-
   g_key_file_free (out);
   g_free (data);
 
@@ -1086,7 +981,7 @@ write_failed:
 /**
  * gst_encoding_target_save:
  * @target: a #GstEncodingTarget
- * @error: If an error occurred, this field will be filled in.
+ * @error: If an error occured, this field will be filled in.
  *
  * Saves the @target to a default user-local directory.
  *
@@ -1111,8 +1006,7 @@ gst_encoding_target_save (GstEncodingTarget * target, GError ** error)
   if (g_mkdir_with_parents (dirname, 0755)) {
     GST_ERROR_OBJECT (target, "Could not create directory to save %s into: %s",
         target->name, g_strerror (errno));
-    g_free (dirname);
-    g_free (lfilename);
+
     return FALSE;
   }
   filename = g_build_filename (dirname, lfilename, NULL);
@@ -1212,12 +1106,10 @@ sub_get_all_targets (gchar * subdir)
     fullname = g_build_filename (subdir, filename, NULL);
     target = gst_encoding_target_load_from_file (fullname, NULL);
     if (target) {
-      target->path = fullname;
       res = g_list_append (res, target);
-    } else {
+    } else
       GST_WARNING ("Failed to get a target from %s", fullname);
-      g_free (fullname);
-    }
+    g_free (fullname);
   }
   g_dir_close (dir);
 
@@ -1287,7 +1179,7 @@ merge_targets (GList * res, GList * extra)
 
 /**
  * gst_encoding_list_all_targets:
- * @categoryname: (nullable): The category, for ex: #GST_ENCODING_CATEGORY_DEVICE.
+ * @categoryname: (allow-none): The category, for ex: #GST_ENCODING_CATEGORY_DEVICE.
  * Can be %NULL.
  *
  * List all available #GstEncodingTarget for the specified category, or all categories
